const fetch = require('node-fetch');
const CSGOProfile = require('./CSGOProfile');
const RocketLeagueProfile = require('./RocketLeagueProfile');
const OverwatchProfile = require('./OverwatchProfile');
const MinecraftProfile = require('./MinecraftProfile');

class Client {
    constructor(options) {
        options = options || {};
        this.steam = options.steam;
        this.rocket = options.rocket;
    }

    getCSGOProfile(username) {
        return new Promise((resolve, reject) => {
            fetch(`http://api.steampowered.com/ISteamUserStats/GetUserStatsForGame/v0002/?appid=730&key=${this.steam}&steamid=${username}`)
                .then(res => res.json())
                .then(json => resolve(new CSGOProfile(json)))
                .catch(err => reject(err));
        });
    }

    getRocketLeagueProfile(username, platform) {
        return new Promise((resolve, reject) => {
            fetch(`https://api.rocketleaguestats.com/v1/player?unique_id=${username}&platform_id=${RLplatforms[platform] || platform}&apikey=${this.rocket}`)
                .then(res => res.json())
                .then(json => resolve(new RocketLeagueProfile(json)))
                .catch(err => reject(err));
        });
    }

    getOverwatchProfile(username, mode, region) {
        return new Promise((resolve, reject) => {
            fetch(`https://owapi.net/api/v3/u/${username.replace('#', '-')}/stats`)
                .then(res => res.json())
                .then(json => resolve(new OverwatchProfile(json[region].stats[mode])))
                .catch(err => reject(err));
        });
    }

    getMinecraftProfile(server) {
        return new Promise((resolve, reject) => {
            fetch(`https://mcapi.ca/query/${server}/info`)
                .then(res => res.json())
                .then(json => resolve(new MinecraftProfile(json)))
                .catch(err => reject(err));
        });
    }
}

const RLplatforms = {
    'steam': '1',
    'pc': '1',
    'computer': '1',
    'psn': '2',
    'playstation': '2',
    'ps4': '2',
    'xbl': '3',
    'xbox': '3',
    'xb1': '3'
};

module.exports.Client = Client;
